========
gazelib
========

This **Python** package provides software tools to manage and analyze **gaze data from eye-trackers**.

Gazelib is developed at `Infant Cognition Laboratory
<http://www.uta.fi/med/icl/index.html>`_ at University of Tampere.

.. image:: https://travis-ci.org/infant-cognition-tampere/gazelib.svg
  :target: https://travis-ci.org/infant-cognition-tampere/gazelib
  :alt: Travis CI build status
.. image:: https://coveralls.io/repos/infant-cognition-tampere/gazelib/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/infant-cognition-tampere/gazelib?branch=master
  :alt: Coveralls.io test coverage
.. image:: https://readthedocs.org/projects/gazelib/badge/
  :target: http://gazelib.readthedocs.org/en/latest/
  :alt: ReadTheDocs documentation status
.. image:: https://badge.fury.io/py/gazelib.svg
  :target: https://pypi.python.org/pypi/gazelib
  :alt: PyPI package version


Install
==========

With `pip
<https://pypi.python.org/pypi/gazelib>`_::

    $ pip install gazelib



Docs
======

Examples and API docs are available at `http://gazelib.readthedocs.org/
<http://gazelib.readthedocs.org/>`_.



For developers
=================

Tips, conventions, and specifications for the developers are available at `wiki
<https://github.com/infant-cognition-tampere/gazelib/wiki>`_.



Versioning
=============

`Semantic Versioning 2.0.0
<http://semver.org/>`_



License
==========

`GNU General Public License version 3
<http://www.gnu.org/licenses/>`_
